@@ -3,7 +3,7 @@
 #' A set of generators for date vectors.
 #'
 #' @template len
-#' @template frac_na
+#' @template any_na
 #' @template left
 #' @template right
 #'
@@ -13,34 +13,35 @@
 #'   left = as.Date("2020-01-01"),
 #'   right = as.Date("2020-01-10")
 #' ) |> show_example()
-#' date_(len = 10L, frac_na = 0.5) |> show_example()
+#' date_(len = 10L, any_na = TRUE) |> show_example()
 #' @template generator
 #' @export
-date_ <- function(len = 1L, frac_na = 0) {
-  date_bounded(min_date(), max_date(), len, frac_na)
+date_ <- function(len = c(1L, 10L), any_na = FALSE) {
+  date_bounded(min_date(), max_date(), len, any_na)
 }
 
 #' @rdname date_
 #' @export
-date_bounded <- function(left, right, len = 1L, frac_na = 0) {
+date_bounded <- function(left, right, len = c(1L, 10L), any_na = FALSE) {
   qc_gen(\(len2 = len)
     seq(left, right, by = "day") |>
       hedgehog::gen.element() |>
-      replace_frac_with(NA_real_, frac_na) |>
+      replace_some_with(NA_real_, any_na) |>
+      hedgehog::gen.with(as.Date) |>
       vectorize(len2)
   )
 }
 
 #' @rdname date_
 #' @export
-date_left_bounded <- function(left, len = 1L, frac_na = 0) {
-  date_bounded(left, max_date(), len, frac_na)
+date_left_bounded <- function(left, len = c(1L, 10L), any_na = FALSE) {
+  date_bounded(left, max_date(), len, any_na)
 }
 
 #' @rdname date_
 #' @export
-date_right_bounded <- function(right, len = 1L, frac_na = 0) {
-  date_bounded(min_date(), right, len, frac_na)
+date_right_bounded <- function(right, len = c(1L, 10L), any_na = FALSE) {
+  date_bounded(min_date(), right, len, any_na)
 }
 
 min_date <- function() {
