@@ -3,18 +3,19 @@
 #' A generator for factor vectors.
 #'
 #' @template len
-#' @template frac_na
+#' @template any_na
 #'
 #' @examples
 #' factor_() |> show_example()
-#' factor_(len = 10L, frac_na = 0.5) |> show_example()
+#' factor_(len = 10L, any_na = TRUE) |> show_example()
 #' @template generator
 #' @export
-factor_ <- function(len = 1L, frac_na = 0) {
+factor_ <- function(len = c(1L, 10L), any_na = FALSE) {
   qc_gen(\(len2 = len)
-    character_()() |>
+    character_(len = 1L) |>
+      as_hedgehog() |>
       hedgehog::gen.with(as.factor) |>
-      replace_frac_with(NA_integer_, frac_na) |>
+      replace_some_with(NA_integer_, any_na) |>
       vectorize(len2)
   )
 }
