@@ -1,14 +1,14 @@
-test_that("one_of with single generator doesn't change generator", {
+test_that("one_of doesn't modify a single generator", {
   for_all(
-    a = any_vector(),
+    a = anything(),
     property = \(a) {
       for_all(
         b = one_of(constant(a)),
         property = \(b) expect_equal(a, b),
-        tests = 10L
+        tests = nested_tests()
       )
     },
-    tests = 10L
+    tests = nested_tests()
   )
 })
 
@@ -19,7 +19,7 @@ test_that("one_of can ignore the first generator", {
       integer_negative(),
       prob = c(0, 1)
     ),
-    property = \(a) expect_true(a < 0L)
+    property = \(a) all(a < 0L) |> expect_true()
   )
 })
 
@@ -30,6 +30,6 @@ test_that("one_of can ignore the second generator", {
       integer_negative(),
       prob = c(1, 0)
     ),
-    property = \(a) expect_true(a > 0L)
+    property = \(a) all(a > 0L) |> expect_true()
   )
 })
