@@ -1,5 +1,5 @@
 test_that("quickcheck generators print correctly", {
-  print(integer_()) |> expect_output("Hedgehog generator:")
+  print(integer_()) |> expect_output("Quickcheck generator:")
 
   print(integer_()) |> expect_output("Example:")
 
@@ -7,7 +7,3 @@ test_that("quickcheck generators print correctly", {
 
   print(constant(TRUE)) |> expect_output("TRUE")
 })
-
-test_that("show_example returns an example", {
-  constant("hello") |> show_example() |> expect_equal("hello")
-})
